<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Address ServiceType
 * @subpackage Services
 */
class Address extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named addressReeksPostcodeSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Get an address by providing its complete postcode (including house number). This is a reeks level function.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressReeksPostcodeSearchRequestType $parameters
     * @return \StructType\AddressReeksPostcodeSearchResponseType|bool
     */
    public function addressReeksPostcodeSearch(\StructType\AddressReeksPostcodeSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressReeksPostcodeSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressReeksAddressSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Get an address by providing the address, postcode, city. This is a reeks level function.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressReeksAddressSearchRequestType $parameters
     * @return \StructType\AddressReeksAddressSearchResponseType|bool
     */
    public function addressReeksAddressSearch(\StructType\AddressReeksAddressSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressReeksAddressSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressReeksFullParameterSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look for an address by province, municipality, city, street, house number and house number addition. Returns a list of matches. This is a reeks level function.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressReeksFullParameterSearchRequestType $parameters
     * @return \StructType\AddressReeksFullParameterSearchResponseType|bool
     */
    public function addressReeksFullParameterSearch(\StructType\AddressReeksFullParameterSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressReeksFullParameterSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressReeksParameterSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look for an address by province, municipality, city, street, house number and house number addition. Returns a list of matches. This is a reeks level function.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressReeksParameterSearchRequestType $parameters
     * @return \StructType\AddressReeksParameterSearchResponseType|bool
     */
    public function addressReeksParameterSearch(\StructType\AddressReeksParameterSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressReeksParameterSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressPerceelPhraseSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look for an perceel address by simply providing a phrase such as "Somestreet 123". Returns a list of matches. This is a perceel level function (more accurate than reeks level).
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressPerceelPhraseSearchRequestType $parameters
     * @return \StructType\AddressPerceelPhraseSearchResponseType|bool
     */
    public function addressPerceelPhraseSearch(\StructType\AddressPerceelPhraseSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressPerceelPhraseSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named
     * addressPerceelFullParameterSearchV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look for an perceel address by province, municipality, city, street, house number and house number addition. Returns a list of matches This is a perceel level function (more accurate than reeks level).
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressPerceelFullParameterSearchV2RequestType $parameters
     * @return \StructType\AddressPerceelFullParameterSearchV2ResponseType|bool
     */
    public function addressPerceelFullParameterSearchV2(\StructType\AddressPerceelFullParameterSearchV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressPerceelFullParameterSearchV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressProvinceListNeighborhoods
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all neighborhood codes in the province
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressProvinceListNeighborhoodsRequestType $parameters
     * @return \StructType\AddressProvinceListNeighborhoodsResponseType|bool
     */
    public function addressProvinceListNeighborhoods(\StructType\AddressProvinceListNeighborhoodsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressProvinceListNeighborhoods($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressProvinceListDistricts
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of municipalities which are in the specified province
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressProvinceListDistrictsRequestType $parameters
     * @return \StructType\AddressProvinceListDistrictsResponseType|bool
     */
    public function addressProvinceListDistricts(\StructType\AddressProvinceListDistrictsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressProvinceListDistricts($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressProvinceList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all provinces
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressProvinceListRequestType $parameters
     * @return \StructType\AddressProvinceListResponseType|bool
     */
    public function addressProvinceList(\StructType\AddressProvinceListRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressProvinceList($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressProvinceSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of provinces which match the given name
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressProvinceSearchRequestType $parameters
     * @return \StructType\AddressProvinceSearchResponseType|bool
     */
    public function addressProvinceSearch(\StructType\AddressProvinceSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressProvinceSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressDistrictSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of municipalities which match the given name
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressDistrictSearchRequestType $parameters
     * @return \StructType\AddressDistrictSearchResponseType|bool
     */
    public function addressDistrictSearch(\StructType\AddressDistrictSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressDistrictSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressDistrictListCities
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of cities which are in the specified municipality
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressDistrictListCitiesRequestType $parameters
     * @return \StructType\AddressDistrictListCitiesResponseType|bool
     */
    public function addressDistrictListCities(\StructType\AddressDistrictListCitiesRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressDistrictListCities($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressDistrictListNeighborhoods
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all neighborhood codes in the municipality
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressDistrictListNeighborhoodsRequestType $parameters
     * @return \StructType\AddressDistrictListNeighborhoodsResponseType|bool
     */
    public function addressDistrictListNeighborhoods(\StructType\AddressDistrictListNeighborhoodsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressDistrictListNeighborhoods($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressCitySearchV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search for all cities that match a phrase. Cities are also matched if input matches a commonly used alternative city name. Exact matches on the official name are listed first, the rest of the results is sorted alphabetically.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressCitySearchV2RequestType $parameters
     * @return \StructType\AddressCitySearchV2ResponseType|bool
     */
    public function addressCitySearchV2(\StructType\AddressCitySearchV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressCitySearchV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressCityListNeighborhoods
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all neighborhood codes in the city
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressCityListNeighborhoodsRequestType $parameters
     * @return \StructType\AddressCityListNeighborhoodsResponseType|bool
     */
    public function addressCityListNeighborhoods(\StructType\AddressCityListNeighborhoodsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressCityListNeighborhoods($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressPerceelFullParameterSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This is a deprecated function. Please use "addressPerceelFullParameterSearchV2" instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressPerceelFullParameterSearchRequestType $parameters
     * @return \StructType\AddressPerceelFullParameterSearchResponseType|bool
     */
    public function addressPerceelFullParameterSearch(\StructType\AddressPerceelFullParameterSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressPerceelFullParameterSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressPerceelParameterSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This is a deprecated function. Please use "addressPerceelFullParameterSearchV2" or "addressPerceelPhraseSearch" instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressPerceelParameterSearchRequestType $parameters
     * @return \StructType\AddressPerceelParameterSearchResponseType|bool
     */
    public function addressPerceelParameterSearch(\StructType\AddressPerceelParameterSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressPerceelParameterSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressReeksPhraseSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This function is deprecated and will not be available in the future. Use "addressReeksAddressSearch" or "addressReeksFullParameterSearch" instead.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressReeksPhraseSearchRequestType $parameters
     * @return \StructType\AddressReeksPhraseSearchResponseType|bool
     */
    public function addressReeksPhraseSearch(\StructType\AddressReeksPhraseSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressReeksPhraseSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressNeighborhoodName
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This function is about to be removed!
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressNeighborhoodNameRequestType $parameters
     * @return \StructType\AddressNeighborhoodNameResponseType|bool
     */
    public function addressNeighborhoodName(\StructType\AddressNeighborhoodNameRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressNeighborhoodName($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named addressNeighborhoodPhraseSearch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: This function is about to be removed!
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\AddressNeighborhoodPhraseSearchRequestType $parameters
     * @return \StructType\AddressNeighborhoodPhraseSearchResponseType|bool
     */
    public function addressNeighborhoodPhraseSearch(\StructType\AddressNeighborhoodPhraseSearchRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->addressNeighborhoodPhraseSearch($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\AddressCityListNeighborhoodsResponseType|\StructType\AddressCitySearchV2ResponseType|\StructType\AddressDistrictListCitiesResponseType|\StructType\AddressDistrictListNeighborhoodsResponseType|\StructType\AddressDistrictSearchResponseType|\StructType\AddressNeighborhoodNameResponseType|\StructType\AddressNeighborhoodPhraseSearchResponseType|\StructType\AddressPerceelFullParameterSearchResponseType|\StructType\AddressPerceelFullParameterSearchV2ResponseType|\StructType\AddressPerceelParameterSearchResponseType|\StructType\AddressPerceelPhraseSearchResponseType|\StructType\AddressProvinceListDistrictsResponseType|\StructType\AddressProvinceListNeighborhoodsResponseType|\StructType\AddressProvinceListResponseType|\StructType\AddressProvinceSearchResponseType|\StructType\AddressReeksAddressSearchResponseType|\StructType\AddressReeksFullParameterSearchResponseType|\StructType\AddressReeksParameterSearchResponseType|\StructType\AddressReeksPhraseSearchResponseType|\StructType\AddressReeksPostcodeSearchResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
