<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Compliance ServiceType
 * @subpackage Services
 */
class Compliance extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named complianceSearchPersons
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a list of person entities based on search criteria
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\ComplianceSearchPersonsRequestType $parameters
     * @return \StructType\ComplianceSearchPersonsResponseType|bool
     */
    public function complianceSearchPersons(\StructType\ComplianceSearchPersonsRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->complianceSearchPersons($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named complianceGetPerson
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a person entity based on a provided id
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\ComplianceGetPersonRequestType $parameters
     * @return \StructType\ComplianceGetPersonResponseType|bool
     */
    public function complianceGetPerson(\StructType\ComplianceGetPersonRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->complianceGetPerson($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named complianceSearchBusinesses
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a list of business entities based on search criteria
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\ComplianceSearchBusinessesRequestType $parameters
     * @return \StructType\ComplianceSearchBusinessesResponseType|bool
     */
    public function complianceSearchBusinesses(\StructType\ComplianceSearchBusinessesRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->complianceSearchBusinesses($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named complianceGetBusiness
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a business based on a provided id
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\ComplianceGetBusinessRequestType $parameters
     * @return \StructType\ComplianceGetBusinessResponseType|bool
     */
    public function complianceGetBusiness(\StructType\ComplianceGetBusinessRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->complianceGetBusiness($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\ComplianceGetBusinessResponseType|\StructType\ComplianceGetPersonResponseType|\StructType\ComplianceSearchBusinessesResponseType|\StructType\ComplianceSearchPersonsResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
