<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Kvk ServiceType
 * @subpackage Services
 */
class Kvk extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named kvkGetDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve data on a business establishment
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkGetDossierRequestType $parameters
     * @return \StructType\KvkGetDossierResponseType|bool
     */
    public function kvkGetDossier(\StructType\KvkGetDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkGetDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkSearchDossierNumber
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search for business establishments using a known identifier
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkSearchDossierNumberRequestType $parameters
     * @return \StructType\KvkSearchDossierNumberResponseType|bool
     */
    public function kvkSearchDossierNumber(\StructType\KvkSearchDossierNumberRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkSearchDossierNumber($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkSearchParameters
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find business establishments using a variety of parameters
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkSearchParametersRequestType $parameters
     * @return \StructType\KvkSearchParametersResponseType|bool
     */
    public function kvkSearchParameters(\StructType\KvkSearchParametersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkSearchParameters($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkSearchPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Find business establishments based on postcode and house number
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkSearchPostcodeRequestType $parameters
     * @return \StructType\KvkSearchPostcodeResponseType|bool
     */
    public function kvkSearchPostcode(\StructType\KvkSearchPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkSearchPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkSearchSelection
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Search for businesses matching all of the given criteria.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkSearchSelectionRequestType $parameters
     * @return \StructType\KvkSearchSelectionResponseType|bool
     */
    public function kvkSearchSelection(\StructType\KvkSearchSelectionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkSearchSelection($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkGetExtractDocument
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve a Chamber of Commerce extract document (Dutch: Uittreksel Handelsregister)
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkGetExtractDocumentRequestType $parameters
     * @return \StructType\KvkGetExtractDocumentResponseType|bool
     */
    public function kvkGetExtractDocument(\StructType\KvkGetExtractDocumentRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkGetExtractDocument($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkUpdateCheckDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve information on the last change of a business establishment
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkUpdateCheckDossierRequestType $parameters
     * @return \StructType\KvkUpdateCheckDossierResponseType|bool
     */
    public function kvkUpdateCheckDossier(\StructType\KvkUpdateCheckDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkUpdateCheckDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkUpdateGetChangedDossiers
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve all dossiers changed since the given date.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkUpdateGetChangedDossiersRequestType $parameters
     * @return \StructType\KvkUpdateGetChangedDossiersResponseType|bool
     */
    public function kvkUpdateGetChangedDossiers(\StructType\KvkUpdateGetChangedDossiersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkUpdateGetChangedDossiers($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkUpdateGetDossiers
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all dossiers that have been updated since they were last retrieved by the user
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkUpdateGetDossiersRequestType $parameters
     * @return \StructType\KvkUpdateGetDossiersResponseType|bool
     */
    public function kvkUpdateGetDossiers(\StructType\KvkUpdateGetDossiersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkUpdateGetDossiers($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkUpdateAddDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Add a dossier to the list of dossiers for which the user (the user whose credentials are used to make the call) wants to receive updates
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkUpdateAddDossierRequestType $parameters
     * @return \StructType\KvkUpdateAddDossierResponseType|bool
     */
    public function kvkUpdateAddDossier(\StructType\KvkUpdateAddDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkUpdateAddDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named kvkUpdateRemoveDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Remove a dossier from the list of dossiers for which the user (the user whose credentials are used to make the call) wants to receive updates.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\KvkUpdateRemoveDossierRequestType $parameters
     * @return \StructType\KvkUpdateRemoveDossierResponseType|bool
     */
    public function kvkUpdateRemoveDossier(\StructType\KvkUpdateRemoveDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->kvkUpdateRemoveDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\KvkGetDossierResponseType|\StructType\KvkGetExtractDocumentResponseType|\StructType\KvkSearchDossierNumberResponseType|\StructType\KvkSearchParametersResponseType|\StructType\KvkSearchPostcodeResponseType|\StructType\KvkSearchSelectionResponseType|\StructType\KvkUpdateAddDossierResponseType|\StructType\KvkUpdateCheckDossierResponseType|\StructType\KvkUpdateGetChangedDossiersResponseType|\StructType\KvkUpdateGetDossiersResponseType|\StructType\KvkUpdateRemoveDossierResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
