<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Map ServiceType
 * @subpackage Services
 */
class Map extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named mapViewPostcodeV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a map in JPG or PNG format showing the location of the given postcode
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\MapViewPostcodeV2RequestType $parameters
     * @return \StructType\MapViewPostcodeV2ResponseType|bool
     */
    public function mapViewPostcodeV2(\StructType\MapViewPostcodeV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->mapViewPostcodeV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named mapViewLatLon
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a map showing the location of the given coordinate (centerlat, centerlon). extra_latlon is an array of other locations to be shown. format can be 'jpg' or 'png' (default). The width and height parameters can be [1 - 2048].
     * Scale in meters per pixel [0.298 - 156412]
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\MapViewLatLonRequestType $parameters
     * @return \StructType\MapViewLatLonResponseType|bool
     */
    public function mapViewLatLon(\StructType\MapViewLatLonRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->mapViewLatLon($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named mapViewRD
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a map showing the location of the given Rijksdriehoeksmeting coordinate (centerx, centery). extra_xy is an array of other locations to be shown. format can be 'jpg' or 'png' (default). The width and height parameters can be
     * [1-2048]. Scale in meters per pixel [0.298 - 156412]
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\MapViewRDRequestType $parameters
     * @return \StructType\MapViewRDResponseType|bool
     */
    public function mapViewRD(\StructType\MapViewRDRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->mapViewRD($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named mapViewInternationalLatLon
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a map showing the location of the given coordinate (latitude, longitude)
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\MapViewInternationalLatLonRequestType $parameters
     * @return \StructType\MapViewInternationalLatLonResponseType|bool
     */
    public function mapViewInternationalLatLon(\StructType\MapViewInternationalLatLonRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->mapViewInternationalLatLon($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\MapViewInternationalLatLonResponseType|\StructType\MapViewLatLonResponseType|\StructType\MapViewPostcodeV2ResponseType|\StructType\MapViewRDResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
